@@ -422,12 +422,12 @@ def shell(ctx, config):
 
 
 @task
-def manage(ctx, config, cmd):
+def manage(ctx, config, cmd, tag=None):
     """Exec into the management container"""
     set_context(ctx, config)
     settings_dict = get_settings()
     config_dict = settings_dict['configs'][config]
-    management_cmd = build_management_cmd(config_dict, f'python manage.py {cmd}')
+    management_cmd = build_management_cmd(config_dict, f'python manage.py {cmd}', tag)
     ctx.run(management_cmd, pty=True, warn=False, echo=True)
 
 
